//
//  ImagePickerCollectionCell.swift
//  image_picker_ios
//
//  Created by Seifeddine Bouzid on 04.05.23.
//

import Foundation

class ImagePickerCollectionCell: UICollectionViewCell {
    lazy var imageView = UIImageView()
    lazy var imageViewOverlay = UIImageView()
    lazy var selectedImageView = UIImageView()
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        configureAndAddView(view: imageView)
        configureAndAddView(view: imageViewOverlay)
        configureAndAddView(view: selectedImageView)
        configureImageViewConstraints(view: imageView)
        configureImageViewConstraints(view: imageViewOverlay)
        configureSelectedImageViewConstraints()
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    private func configureAndAddView(view: UIView) {
        view.contentMode = .scaleAspectFill
        view.clipsToBounds = true
        view.translatesAutoresizingMaskIntoConstraints = false
        contentView.addSubview(view)
    }
    
    private func configureImageViewConstraints(view: UIView) {
        NSLayoutConstraint.activate([
            NSLayoutConstraint(item: view,
                               attribute: .centerX,
                               relatedBy: .equal,
                               toItem: self,
                               attribute: .centerX,
                               multiplier: 1,
                               constant: 0),
            NSLayoutConstraint(item: view,
                               attribute: .centerY,
                               relatedBy: .equal,
                               toItem: self,
                               attribute: .centerY,
                               multiplier: 1,
                               constant: 0),
            NSLayoutConstraint(item: view,
                               attribute: .width,
                               relatedBy: .equal,
                               toItem: self,
                               attribute: .width,
                               multiplier: 1,
                               constant: 0),
            NSLayoutConstraint(item: view,
                               attribute: .height,
                               relatedBy: .equal,
                               toItem: self,
                               attribute: .height,
                               multiplier: 1,
                               constant: 0)
        ])
    }
    
    private func configureSelectedImageViewConstraints() {
        NSLayoutConstraint.activate([
            NSLayoutConstraint(item: selectedImageView,
                               attribute: .trailing,
                               relatedBy: .equal,
                               toItem: self,
                               attribute: .trailing,
                               multiplier: 1,
                               constant: -4),
            NSLayoutConstraint(item: selectedImageView,
                               attribute: .bottom,
                               relatedBy: .equal,
                               toItem: self,
                               attribute: .bottom,
                               multiplier: 1,
                               constant: -4),
            NSLayoutConstraint(item: selectedImageView,
                               attribute: .width,
                               relatedBy: .equal,
                               toItem: nil,
                               attribute: .notAnAttribute,
                               multiplier: 1,
                               constant: 22),
            NSLayoutConstraint(item: selectedImageView,
                               attribute: .height,
                               relatedBy: .equal,
                               toItem: nil,
                               attribute: .notAnAttribute,
                               multiplier: 1,
                               constant: 22)
        ])
    }
    
    func configureCell(image: UIImage) {
        imageView.image = image
    }
    
    func check() {
        imageViewOverlay.backgroundColor = .black.withAlphaComponent(0.3)
        selectedImageView.image = ImagePickerHelper.getCheckMarkImage()
    }
    
    func unCheck() {
        imageViewOverlay.backgroundColor = .clear
        selectedImageView.image = nil
    }
}
