//
//  ImagePickerHelper.swift
//  image_picker_ios
//
//  Created by Seifeddine Bouzid on 04.05.23.
//

import Foundation
import Photos

class ImagePickerHelper {
    
    static func getCheckMarkImage() -> UIImage? {
        guard let bundleUrl = Bundle(for: self).url(forResource: "ScanbotImagePickerBundle", withExtension: "bundle") else {
            return nil
        }
        
        guard let bundle = Bundle(url: bundleUrl) else { 
            return nil 
            
        }
        return UIImage(named: "check", in: bundle, compatibleWith: nil)
    }
    
    static func getImageFromAsset(_ asset: PHAsset, 
                                  size: CGSize = CGSize(width: 240, height: 320),
                                  completion: @escaping (_ img: UIImage) -> Void) {
        let options = PHImageRequestOptions()
        options.resizeMode = .exact
        options.isNetworkAccessAllowed = true
        options.isSynchronous = true
        options.normalizedCropRect = CGRect(x: 0, y: 0, width: 127, height: 127)
        PHImageManager.default().requestImage(for: asset,
                                              targetSize: size,
                                              contentMode: .aspectFit,
                                              options: options) { image, info in
           
            if let image {
                DispatchQueue.main.async {
                    completion(image)
                }
            }
        }
    }
    
    static func fetchAssets(completion: @escaping (_ assets: [PHAsset]) -> Void) {
        
        DispatchQueue.global(qos: .background).async {
            let results = PHAsset.fetchAssets(with: .image, options: PHFetchOptions())
            
            if results.count > 0 {
                var assets = [PHAsset]()
                results.enumerateObjects({ object, _, _ in
                    assets.insert(object, at: 0)
                })
                
                DispatchQueue.main.async {
                    completion(assets)
                }
            }
        }
    }
}
