/// Image Picker Response class handles data received from Flutter/Native image pickers.
class ImagePickerResponse {
  /// Use this proeprty when pickImageAsync function is invoked.
  String? uri;

  /// Use this property when pickImagesAsync function is invoked.
  List<String>? uris;

  /// Use this proeprty to prompt a message if there is any error.
  String? message;

  /// Constructor for Multiple images response.
  ImagePickerResponse.withImagesResponse({this.uris, this.message});

  /// Constructor for Single image response.
  ImagePickerResponse.withImageResponse({this.uri, this.message});

  /// De-serialises to object from Json string
  ImagePickerResponse.fromJson(Map<String, dynamic> json) {
    uris = json['uris'].cast<String>();
    message = json['message'];
  }

  /// Serialises object to Json string
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['uris'] = uris;
    data['message'] = message;
    return data;
  }

  /// helper method to convert list of uris to list string paths
  List<String> UrisToStringPaths(List<Uri>? uris) {
    var list = List<String>.empty(growable: true);
    if (uris != null && uris.isNotEmpty) {
      for (var uriItem in uris) {
        list.add(uriItem.path);
      }
    }
    return list;
  }

  /// helper method to convert list of string paths to list uris
  List<Uri> PathsToUris(List<String>? paths) {
    var list = List<Uri>.empty(growable: true);
    if (paths != null && paths.isNotEmpty) {
      for (var path in paths) {
        if (path.isNotEmpty) {
          list.add(Uri(path: path));
        }
      }
    }
    return list;
  }

  /// get the non empty list of string
  List<String> getNonEmptyUris() {
    var list = List<String>.empty(growable: true);
    if (uris == null || uris!.isEmpty) {
      return list;
    }

    for (var uriItem in uris!) {
      if (uriItem.isNotEmpty) {
        list.add(uriItem);
      }
    }
    return list;
  }
}
